const crypto = require('crypto')

/**
 * Generate SRI hashes.
 * @param {string} data Data to hash
 * @param {string|Array<string>} [algorithms] Algorithms to generate hashes (Default to `sha384`)
 */
function sri(data, algorithms) {
    if (typeof algorithms === 'string') {
        algorithms = [algorithms]
    } else if (!Array.isArray(algorithms)) {
        throw new Error('sri: type of `algorithms` argument should be string or array of strings')
    }

    algorithms = algorithms || ['sha384']

    return algorithms.map((algorithm) => {
        const hash = crypto
            .createHash(algorithm)
            .update(data, 'utf8')
            .digest('base64')

        return algorithm + '-' + hash
    }).join(' ')
}

module.exports = sri
